@@ -39,6 +39,9 @@ class Dynamo(object):
     def init_settings(self):
         """Initialize all of the extension settings."""
         self.app.config.setdefault('DYNAMO_TABLES', [])
+        self.app.config.setdefault('DYNAMO_ENABLE_LOCAL', environ.get('DYNAMO_ENABLE_LOCAL', False))
+        self.app.config.setdefault('DYNAMO_LOCAL_HOST', environ.get('DYNAMO_LOCAL_HOST'))
+        self.app.config.setdefault('DYNAMO_LOCAL_PORT', environ.get('DYNAMO_LOCAL_PORT'))
         self.app.config.setdefault('AWS_ACCESS_KEY_ID', environ.get('AWS_ACCESS_KEY_ID'))
         self.app.config.setdefault('AWS_SECRET_ACCESS_KEY', environ.get('AWS_SECRET_ACCESS_KEY'))
         self.app.config.setdefault('AWS_REGION', environ.get('AWS_REGION', self.DEFAULT_REGION))
@@ -57,6 +60,9 @@ class Dynamo(object):
         if not (self.app.config['AWS_ACCESS_KEY_ID'] and self.app.config['AWS_SECRET_ACCESS_KEY']):
             raise ConfigurationError('You must specify your AWS credentials.')
 
+        if self.app.config['DYNAMO_ENABLE_LOCAL'] and not (self.app.config['DYNAMO_LOCAL_HOST'] and self.app.config['DYNAMO_LOCAL_PORT']):
+            raise ConfigurationError('If you have enabled Dynamo local, you must specify the host and port.')
+
     @property
     def connection(self):
         """
@@ -68,11 +74,21 @@ class Dynamo(object):
         ctx = stack.top
         if ctx is not None:
             if not hasattr(ctx, 'dynamo_connection'):
-                ctx.dynamo_connection = connect_to_region(
-                    self.app.config['AWS_REGION'],
-                    aws_access_key_id = self.app.config['AWS_ACCESS_KEY_ID'],
-                    aws_secret_access_key = self.app.config['AWS_SECRET_ACCESS_KEY'],
-                )
+                kwargs = {
+                    'aws_access_key_id': self.app.config['AWS_ACCESS_KEY_ID'],
+                    'aws_secret_access_key': self.app.config['AWS_SECRET_ACCESS_KEY'],
+                    'host': self.app.config['DYNAMO_LOCAL_HOST'] if self.app.config['DYNAMO_ENABLE_LOCAL'] else None,
+                    'port': int(self.app.config['DYNAMO_LOCAL_PORT']) if self.app.config['DYNAMO_ENABLE_LOCAL'] else None,
+                    'is_secure': False if self.app.config['DYNAMO_ENABLE_LOCAL'] else True,
+                }
+
+                # If DynamoDB local is disabled, we'll remove these settings.
+                if not kwargs['host']:
+                    del kwargs['host']
+                if not kwargs['port']:
+                    del kwargs['port']
+
+                ctx.dynamo_connection = connect_to_region(self.app.config['AWS_REGION'], **kwargs)
 
             return ctx.dynamo_connection
 
